@@ -14,9 +14,20 @@ if missing_dependencies:
     )
 del hard_dependencies, dependency, missing_dependencies
 
-
+from techind.doubleExponentialMovingAverage import (
+    doubleExponentialMovingAverage as doubleExponentialMovingAverage,
+)
 from techind.exponentialMovingAverage import (
     exponentialMovingAverage as exponentialMovingAverage,
 )
+from techind.kaufmanAdaptiveMovingAverage import (
+    kaufmanAdaptiveMovingAverage as kaufmanAdaptiveMovingAverage,
+)
 from techind.simpleMovingAverage import simpleMovingAverage as simpleMovingAverage
+from techind.triangularMovingAverage import (
+    triangularMovingAverage as triangularMovingAverage,
+)
+from techind.trippleExponentialMovingAverage import (
+    trippleExponentialMovingAverage as trippleExponentialMovingAverage,
+)
 from techind.weightedMovingAverage import weightedMovingAverage as weightedMovingAverage
